flush_to_batcher

Function flush_to_batcher 

fn flush_to_batcher<T, O>(
    updates: &mut Vec<(UpsertKey, T, UpsertDiff<O>)>,
    chunker: &mut ColumnChunker<(UpsertKey, T, UpsertDiff<O>)>,
    batcher: &mut ColumnMergeBatcher<UpsertKey, T, UpsertDiff<O>>,
)
where T: Columnar + Default + Clone + PartialOrder, for<'a> Ref<'a, T>: Copy + Ord, O: Columnar + Default + Ord + Clone, for<'a> Ref<'a, O>: Ord,
Consolidate updates through chunker into Column chunks and push them into batcher, emptying updates (keeping its capacity). The chunker readies a fully-consolidated chunk per push_into, so the extract loop drains everything it produced.